==> apache-camel-3.10.0-src.zip: apache-camel-3.10.0/components/camel-pubnub/src/main/java/org/apache/camel/component/pubnub/PubNubComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.pubnub;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;
import org.apache.camel.util.ObjectHelper;

@Component("pubnub")
public class PubNubComponent extends DefaultComponent {

    public PubNubComponent(CamelContext context) {
        super(context);
    }

    public PubNubComponent() {
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        ObjectHelper.notNull(remaining, "channel");

        PubNubConfiguration pubNubConfiguration = new PubNubConfiguration();
        pubNubConfiguration.setChannel(remaining);
        setProperties(pubNubConfiguration, parameters);

        PubNubEndpoint endpoint = new PubNubEndpoint(uri, this, pubNubConfiguration);
        setProperties(endpoint, parameters);
        return endpoint;
    }

}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/components/camel-pubnub/src/main/java/org/apache/camel/component/pubnub/PubNubComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.pubnub;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.Metadata;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;
import org.apache.camel.util.ObjectHelper;

@Component("pubnub")
public class PubNubComponent extends DefaultComponent {

    @Metadata
    private PubNubConfiguration configuration = new PubNubConfiguration();

    public PubNubComponent(CamelContext context) {
        super(context);
    }

    public PubNubComponent() {
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        ObjectHelper.notNull(remaining, "channel");

        final PubNubConfiguration config
                = this.configuration != null ? this.configuration.copy() : new PubNubConfiguration();

        config.setChannel(remaining);
        PubNubEndpoint endpoint = new PubNubEndpoint(uri, this, config);
        setProperties(endpoint, parameters);
        return endpoint;
    }

    public PubNubConfiguration getConfiguration() {
        return configuration;
    }

    /**
     * The component configurations
     */
    public void setConfiguration(PubNubConfiguration configuration) {
        this.configuration = configuration;
    }
}
